@@ -12,7 +12,7 @@ requests.packages.urllib3.disable_warnings()
 
 
 class Netrc:
-    '''add or clean records in .netrc file'''
+    '''add or clear records in .netrc file'''
 
     def __init__(self, file=None):
         if file is None:
@@ -38,7 +38,7 @@ class Netrc:
                 f.write(rep)
         self._update_info()
 
-    def clean(self):
+    def clear(self):
         '''remove all records'''
         with open(self.file, 'w') as f:
             f.write('')
@@ -77,7 +77,8 @@ def download_data(url, folder=None, file_name=None, session=None):
     folder: str
         the folder to store output files. Default current folder. 
     file_name: str
-        the file name. If None, will parse from web response or url
+        the file name. If None, will parse from web response or url.
+        file_name can be the absolute path if folder is None.
     session: requests.Session() object
         session maintaining connection. Default None
     '''
@@ -90,12 +91,13 @@ def download_data(url, folder=None, file_name=None, session=None):
     r = session.get(url, headers=headers, stream=True, verify=False)
     r.close()
 
-    if not folder:
-        folder = os.getcwd()
     if not file_name:
         file_name = parse_file_name(r)
 
-    file_path = os.path.join(folder, file_name)
+    if folder:
+        file_path = os.path.join(folder, file_name)
+    else:
+        file_path = os.path.abspath(file_name)
 
     local_size = os.path.getsize(file_path) if os.path.exists(file_path) else 0
 
@@ -185,8 +187,8 @@ def download_datas(urls, folder=None, file_names=None):
     folder: str 
         the folder to store output files. Default current folder.
     file_names: iterator
-        iterator contains names of files. Leaving it None if you want the program 
-        to parse them from website
+        iterator contains names of files. Leaving it None if you want the program to parse 
+        them from website. file_names can cantain the absolute paths if folder is None.
 
     Examples:
     ---------
@@ -218,13 +220,17 @@ async def _download_data(session, url, folder=None, file_name=None):
     headers = {'Range': 'bytes=0-4'}
     support_resume = False
 
-    if not folder:
-        folder = os.getcwd()
-
     async with session.get(url, headers=headers, ssl=False) as r:
         if not file_name:
             file_name = parse_file_name(r)
-        file_path = os.path.join(folder, file_name)
+
+        if folder:
+            if not os.path.exists(folder):
+                os.makedirs(folder)
+            file_path = os.path.join(folder, file_name)
+        else:
+            file_path = os.path.abspath(file_name)
+
         local_size = os.path.getsize(
             file_path) if os.path.exists(file_path) else 0
 
@@ -307,10 +313,10 @@ async def creat_tasks(urls, folder, file_names, limit, desc):
     timeout = aiohttp.ClientTimeout()
     async with aiohttp.ClientSession(connector=conn, timeout=timeout, trust_env=True) as session:
         if file_names:
-            tasks = [asyncio.ensure_future(_download_data(session, url, file_names[i]))
+            tasks = [asyncio.ensure_future(_download_data(session, url, folder, file_names[i]))
                      for i, url in enumerate(urls)]
         else:
-            tasks = [asyncio.ensure_future(_download_data(session, url))
+            tasks = [asyncio.ensure_future(_download_data(session, url, folder))
                      for url in urls]
 
         # Total process bar
@@ -332,7 +338,7 @@ def async_download_datas(urls, folder=None, file_names=None, limit=30, desc=''):
         the folder to store output files. Default current folder.
     file_names: iterator
         iterator contains names of files. Leaving it None if you want the program 
-        to parse them from website 
+        to parse them from website. file_names can cantain the absolute paths if folder is None.
     limit: int
         the number of files downloading simultaneously
     desc: str
@@ -352,7 +358,7 @@ def async_download_datas(urls, folder=None, file_names=None, limit=30, desc=''):
     'http://gws-access.ceda.ac.uk/public/nceo_geohazards/LiCSAR_products/106/106D_05049_131313/interferograms/20141117_20150221/20141117_20150221.geo.cc.tif'] 
 
     folder = 'D:\\data'
-    downloader.async_download_datas(urls,folder,limit=3)
+    downloader.async_download_datas(urls,folder,None,desc='interferograms')
     '''
     loop = asyncio.get_event_loop()
     loop.run_until_complete(creat_tasks(urls, folder, file_names, limit, desc))
@@ -423,3 +429,16 @@ def status_ok(urls, limit=200, timeout=60):
     loop.run_until_complete(asyncio.sleep(0))
     loop.close()
     return status_ok
+
+if __name__ == "__main__":
+
+    urls=['http://gws-access.ceda.ac.uk/public/nceo_geohazards/LiCSAR_products/106/106D_05049_131313/interferograms/20141117_20141211/20141117_20141211.geo.unw.tif',
+    'http://gws-access.ceda.ac.uk/public/nceo_geohazards/LiCSAR_products/106/106D_05049_131313/interferograms/20141024_20150221/20141024_20150221.geo.unw.tif',
+    'http://gws-access.ceda.ac.uk/public/nceo_geohazards/LiCSAR_products/106/106D_05049_131313/interferograms/20141024_20150128/20141024_20150128.geo.cc.tif',
+    'http://gws-access.ceda.ac.uk/public/nceo_geohazards/LiCSAR_products/106/106D_05049_131313/interferograms/20141024_20150128/20141024_20150128.geo.unw.tif',
+    'http://gws-access.ceda.ac.uk/public/nceo_geohazards/LiCSAR_products/106/106D_05049_131313/interferograms/20141211_20150128/20141211_20150128.geo.cc.tif',
+    'http://gws-access.ceda.ac.uk/public/nceo_geohazards/LiCSAR_products/106/106D_05049_131313/interferograms/20141117_20150317/20141117_20150317.geo.cc.tif',
+    'http://gws-access.ceda.ac.uk/public/nceo_geohazards/LiCSAR_products/106/106D_05049_131313/interferograms/20141117_20150221/20141117_20150221.geo.cc.tif'] 
+
+    folder = 'E:\\data'
+    async_download_datas(urls,folder,None,desc='interferograms')
\ No newline at end of file
